@@ -156,21 +156,6 @@ enum class LED {
 Q_DECLARE_FLAGS(LEDs, LED)
 Q_FLAG_NS(LEDs)
 
-/**
- * The Gravity enum is used to specify the direction in which geometry changes during resize.
- */
-enum class Gravity {
-    None,
-    Left,
-    Right,
-    Top,
-    Bottom,
-    TopLeft,
-    TopRight,
-    BottomLeft,
-    BottomRight,
-};
-
 enum Layer {
     UnknownLayer = -1,
     FirstLayer = 0,
